isTest top-level constant

Object const isTest

Annotation on a test framework function that introduces a single test.

Used to annotate a test framework function that runs a single test.

Tools, such as IDEs, can show invocations of such function in a file structure view to help the user navigating in large test files.

The first parameter of the function must be the description of the test.

Implementation

const Object isTest = _IsTest();