isTestGroup top-level constant

Object const isTestGroup

Annotation on a test framework function that introduces a group of tests.

Used to annotate a test framework function that runs a group of tests.

Tools, such as IDEs, can show invocations of such function in a file structure view to help the user navigating in large test files.

The first parameter of the function must be the description of the group.

Implementation

const Object isTestGroup = _IsTestGroup();