AlwaysMatch<TEntity> class

A filter that always evaluates to true.

Inheritance

Constructors

AlwaysMatch()
Creates a filter that matches any input.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(TEntity item) bool
Always returns true for any item.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns an empty JSON representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited