And<TEntity> class

Logical AND combining multiple filters

Inheritance
Available extensions

Constructors

And(List<Filter<TEntity>> filters)
Creates a filter that matches when all filters match.
const

Properties

filters → List<Filter<TEntity>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(TEntity item) → bool
Returns true when every filter matches the item.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() → Not<TEntity>

Available on Filter<TEntity>, provided by the FilterOps extension

Negates this filter.
toJson() → Map<String, dynamic>
Serializes the logical AND predicate to JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited