Has<TEntity, TElement> class

List-contains-element filter (e.g., List

Inheritance
Available extensions

Constructors

Has(Field<TEntity, List<TElement>> field, TElement value)
Creates a filter that matches when field (a list) contains value.
const

Properties

field → Field<TEntity, List<TElement>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TElement
final

Methods

matches(TEntity item) → bool
Returns true when the list field contains value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() → Not<TEntity>

Available on Filter<TEntity>, provided by the FilterOps extension

Negates this filter.
toJson() → Map<String, dynamic>
Serializes the has predicate to JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited