InList<TEntity, TValue> class
In list filter
Constructors
Properties
Methods
-
matches(
TEntity item) → bool -
Returns true when the field value is contained in value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes the inclusion predicate to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited