Lt<TEntity, TValue> class

Less than filter

Inheritance
Available extensions

Constructors

Lt(Field<TEntity, TValue> field, TValue value)
Creates a filter that matches when field is less than value.
const

Properties

field → Field<TEntity, TValue>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TValue
final

Methods

matches(TEntity item) → bool
Returns true when the field value is less than value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() → Not<TEntity>

Available on Filter<TEntity>, provided by the FilterOps extension

Negates this filter.
toJson() → Map<String, dynamic>
Serializes the less-than predicate to JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited