Nested<TEntity, TValue> class

Nested object or collection filter

Inheritance
Available extensions

Constructors

Nested(Field<TEntity, TValue> field, Filter filter)
Creates a filter that matches when field matches filter. If TValue is an Iterable, matches if any element in the collection matches the filter. If TValue is a single object, matches if the object matches the filter.
const

Properties

field → Field<TEntity, TValue>
final
filter → Filter
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(TEntity item) → bool
Returns true when the nested value (or any value in its collection) matches filter.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() → Not<TEntity>

Available on Filter<TEntity>, provided by the FilterOps extension

Negates this filter.
toJson() → Map<String, dynamic>
Serializes the nested filter to JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited