Nested<TEntity, TValue> constructor

const Nested<TEntity, TValue>(
  1. Field<TEntity, TValue> field,
  2. Filter filter
)

Creates a filter that matches when field matches filter. If TValue is an Iterable, matches if any element in the collection matches the filter. If TValue is a single object, matches if the object matches the filter.

Implementation

const Nested(this.field, this.filter);