PatchBase<TEntity, TEnum extends Enum> class abstract

Implemented types

Constructors

PatchBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
patchMap → Map<TEnum, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyTo(TEntity entity) → TEntity
Applies this patch to the given entity
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toPatch() → Map<TEnum, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited