visibleForOverriding top-level constant
Object
const visibleForOverriding
Annotation on declaration that should not be used outside of its package.
Used to annotate an instance member that was made public so that it could be overridden but that is not intended to be referenced from outside the defining library.
Tools, such as the analyzer, can provide feedback if
- the annotation is associated with a declaration other than a public instance member in a class or mixin, or
- the member is referenced outside of the defining library.
Implementation
const Object visibleForOverriding = _VisibleForOverriding();