Field<TEntity, TValue> class
Represents a field in a Zorphy entity TEntity with value type TValue.
Used for type-safe query construction and runtime evaluation.
- Available extensions
- Annotations
Constructors
Properties
- getValue → TValue Function(TEntity)?
-
Function to extract the field value from an entity instance.
Optional, but required for in-memory filtering/sorting.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asc(
) → Sort< TEntity> -
Available on Field<
Builds an ascending sort for this field.TEntity, TValue> , provided by the FieldSortOps extension -
contains(
String value) → Contains< TEntity, String?> -
Available on Field<
Builds a contains filter for nullable string fields.TEntity, String?> , provided by the NullableStringFieldOps extension -
contains(
String value) → Contains< TEntity, String> -
Available on Field<
Builds a contains filter for string fields.TEntity, String> , provided by the StringFieldOps extension -
desc(
) → Sort< TEntity> -
Available on Field<
Builds a descending sort for this field.TEntity, TValue> , provided by the FieldSortOps extension -
eq(
TValue value) → Eq< TEntity, TValue> -
Available on Field<
Builds an equality filter for this field.TEntity, TValue> , provided by the FieldOps extension -
filter(
Filter filter) → Nested< TEntity, List< TElement> > -
Available on Field<
Builds a nested filter for a collection field.TEntity, List< , provided by the CollectionFieldOps extensionTElement> > -
filter(
Filter filter) → Nested< TEntity, TValue> -
Available on Field<
Builds a nested filter for this field.TEntity, TValue> , provided by the FieldOps extension -
gt(
TValue value) → Gt< TEntity, TValue> -
Available on Field<
Builds a greater-than filter for this field.TEntity, TValue> , provided by the FieldOps extension -
gte(
TValue value) → Gte< TEntity, TValue> -
Available on Field<
Builds a greater-than-or-equal filter for this field.TEntity, TValue> , provided by the FieldOps extension -
has(
TElement value) → Has< TEntity, TElement> -
Available on Field<
Builds a has filter that matches when the list containsTEntity, List< , provided by the CollectionFieldOps extensionTElement> >value. -
isIn(
List< TValue> values) → InList<TEntity, TValue> -
Available on Field<
Builds an inclusion filter for this field.TEntity, TValue> , provided by the FieldOps extension -
lt(
TValue value) → Lt< TEntity, TValue> -
Available on Field<
Builds a less-than filter for this field.TEntity, TValue> , provided by the FieldOps extension -
lte(
TValue value) → Lte< TEntity, TValue> -
Available on Field<
Builds a less-than-or-equal filter for this field.TEntity, TValue> , provided by the FieldOps extension -
neq(
TValue value) → Neq< TEntity, TValue> -
Available on Field<
Builds an inequality filter for this field.TEntity, TValue> , provided by the FieldOps extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited