Not<TEntity> class
Logical NOT negating a filter
Constructors
Properties
Methods
-
matches(
TEntity item) → bool -
Returns true when the inner filter does not match the
item.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
) → Not< TEntity> -
Available on Filter<
Negates this filter.TEntity> , provided by the FilterOps extension -
toJson(
) → Map< String, dynamic> -
Serializes the logical NOT predicate to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited