Zorphy2 class
Deprecated alias of Zorphy. Behaves identically since zorphy 2.0; will be removed in a later major release.
- Implemented types
Constructors
-
Zorphy2({List<
Type> ? explicitSubTypes = null, ZorphyPreset preset = ZorphyPreset.standard, ZorphyKind kind = ZorphyKind.entity, bool autoId = false, bool generateJson = false, bool explicitToJson = true, bool hidePublicConstructor = false, bool nonSealed = false, bool? generateCompareTo = null, bool? generateCopyWithFn = null, bool? generatePatch = null, bool? generateFilter = null, bool? generateCopyWith = null, bool? generatePropertyHelpers = null, bool? generateEqualsToString = null, bool? generateChangeTo = null, String? typeKey, String? subtypeWireValue, List<String> equalityExcludes = const []}) -
Creates a Zorphy2 annotation with configurable generation options.
const
Properties
- autoId → bool
-
Whether the class owns an auto-generated uuid
idfield — see Zorphy.autoId for the value-semantics caveat and the Zorphy.equalityExcludes opt-out.final -
equalityExcludes
→ List<
String> -
Field names to exclude from
==,hashCode,toJsonLean()andcompareToX()— see Zorphy.equalityExcludes for the full semantics. Defaults to an empty list.final -
explicitSubTypes
→ List<
Type> ? -
Returns explicitly declared subtypes for polymorphic generation.
final
- explicitToJson → bool
-
Returns whether to use explicitToJson in json_serializable.
final
- generateChangeTo → bool?
-
final
- generateCompareTo → bool?
-
final
- generateCopyWith → bool?
-
final
- generateCopyWithFn → bool?
-
final
- generateEqualsToString → bool?
-
final
- generateFilter → bool?
-
Returns whether filter descriptors should be generated
(null = inherit from preset).
final
- generateJson → bool
-
Returns whether JSON serialization code should be generated.
final
- generatePatch → bool?
-
final
- generatePropertyHelpers → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hidePublicConstructor → bool
-
final
- kind → ZorphyKind
-
The semantic kind of this class — see ZorphyKind.
final
- nonSealed → bool
-
final
- preset → ZorphyPreset
-
How much code to generate. Defaults to ZorphyPreset.standard.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtypeWireValue → String?
-
Custom wire value for this subtype - see Zorphy.subtypeWireValue.
final
- typeKey → String?
-
Custom JSON key for polymorphic dispatch - see Zorphy.typeKey.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited